@@ -3,6 +3,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.utils.safestring import mark_safe
 
 from tendenci.apps.directories.models import DirectoryPricing
+from tendenci.apps.directories.affiliates.models import Connection
 from tendenci.apps.directories.forms import DirectoryPricingForm
 from tendenci.apps.directories.models import Category as DirectoryCategory
 from tendenci.apps.theme.templatetags.static import static
@@ -68,4 +69,17 @@ class DirectoryCategoryAdmin(admin.ModelAdmin):
         qs = super(DirectoryCategoryAdmin, self).get_queryset(request)
         return qs.filter(parent__isnull=True)
 
+
+class ConnectionAdmin(admin.ModelAdmin):
+    list_display = ['cat', 'allow_associated_by']
+    fieldsets = (
+        (None, {'fields': ('cat', 'affliated_cats')}),
+    )
+    
+    def allow_associated_by(self, instance):
+        return ', '.join([c.name for c in instance.affliated_cats.all()])
+    allow_associated_by.short_description = 'Can be associated by'
+
+
+admin.site.register(Connection, ConnectionAdmin)
 admin.site.register(DirectoryCategory, DirectoryCategoryAdmin)
