@@ -1,3 +1,4 @@
+
 from django.template import Library
 
 register = Library()
@@ -10,6 +11,7 @@ def entity_options(context, user, entity):
     })
     return context
 
+
 @register.inclusion_tag("entities/nav.html", takes_context=True)
 def entity_nav(context, user, entity=None):
     context.update({
@@ -21,4 +23,15 @@ def entity_nav(context, user, entity=None):
 
 @register.inclusion_tag("entities/search-form.html", takes_context=True)
 def entity_search(context):
-    return context
\ No newline at end of file
+    return context
+
+
+@register.inclusion_tag("entities/top_nav_items.html", takes_context=True)
+def entity_current_app(context, user, entity=None):
+    context.update({
+        "app_object": entity,
+        "user": user
+    })
+
+    print(context.get('nav_object', None))
+    return context
