@@ -1,25 +1,23 @@
-from django.core.urlresolvers import reverse
 from django.db import models
+from django.urls import reverse
 from django.utils.translation import ugettext, ugettext_lazy as _
 from django.contrib.auth.models import User
-from django.contrib.contenttypes import generic
+from django.contrib.contenttypes.fields import GenericRelation
+from django.utils.safestring import mark_safe
 
-from django.shortcuts import get_object_or_404
-
-from django_countries.countries import COUNTRIES
+from django_countries import countries as COUNTRIES
 from localflavor.us.us_states import STATE_CHOICES
 from localflavor.ca.ca_provinces import PROVINCE_CHOICES
 
 from tendenci.apps.forms_builder.forms.settings import FIELD_MAX_LENGTH, LABEL_MAX_LENGTH
 from tendenci.apps.forms_builder.forms.managers import FormManager
-from tendenci.core.perms.models import TendenciBaseModel
-from tendenci.core.perms.object_perms import ObjectPermission
+from tendenci.apps.perms.models import TendenciBaseModel
+from tendenci.apps.perms.object_perms import ObjectPermission
 from tendenci.apps.user_groups.models import Group, GroupMembership
-from tendenci.core.site_settings.utils import get_setting
-from tendenci.core.base.fields import EmailVerificationField
-from tendenci.core.base.utils import checklist_update
-from tendenci.apps.redirects.models import Redirect
+from tendenci.apps.site_settings.utils import get_setting
+from tendenci.apps.base.utils import checklist_update
 from tendenci.libs.abstracts.models import OrderingBaseModel
+from tendenci.apps.user_groups.utils import get_default_group
 
 #STATUS_DRAFT = 1
 #STATUS_PUBLISHED = 2
@@ -32,14 +30,15 @@ FIELD_CHOICES = (
     ("CharField", _("Text")),
     ("CharField/django.forms.Textarea", _("Paragraph Text")),
     ("BooleanField", _("Checkbox")),
-    ("ChoiceField", _("Choose from a list")),
+    ("ChoiceField/django.forms.RadioSelect", _("Single-select - Radio Button")),
+    ("ChoiceField", _("Single-select - From a List")),
     ("MultipleChoiceField/django.forms.CheckboxSelectMultiple", _("Multi-select - Checkboxes")),
-    ("MultipleChoiceField", _("Multi-select - Select Many")),
+    ("MultipleChoiceField", _("Multi-select - From a List")),
     ("EmailVerificationField", _("Email")),
     ("CountryField", _("Countries")),
     ("StateProvinceField", _("States/Provinces")),
     ("FileField", _("File upload")),
-    ("DateField/django.forms.extras.SelectDateWidget", _("Date - Select")),
+    ("DateField/django.forms.widgets.SelectDateWidget", _("Date - Select")),
     ("DateField/django.forms.DateInput", _("Date - Text Input")),
     ("DateTimeField", _("Date/time")),
     ("CharField/tendenci.apps.forms_builder.forms.widgets.Description", _("Description")),
@@ -48,11 +47,21 @@ FIELD_CHOICES = (
 
 FIELD_FUNCTIONS = (
     ("GroupSubscription", _("Subscribe to Group")),
+    ("GroupSubscriptionAuto", _("Subscribe to Group (Auto)")),
     ("EmailFirstName", _("First Name")),
     ("EmailLastName", _("Last Name")),
     ("EmailFullName", _("Full Name")),
     ("EmailPhoneNumber", _("Phone Number")),
     ("Recipients", _("Email to Recipients")),
+    ("company", _("Company")),
+    ("address", _("Address")),
+    ("city", _("City")),
+    ("region", _("Region")),
+    ("state", _("State")),
+    ("zipcode", _("Zip")),
+    ("position_title", _("Position Title")),
+    ("referral_source", _("Referral Source")),
+    ("notes", _("Notes")),
 )
 
 BILLING_PERIOD_CHOICES = (
@@ -110,6 +119,7 @@ class Form(TendenciBaseModel):
     completion_url = models.CharField(_("Completion URL"), max_length=1000, blank=True, null=True,
         help_text=_("Redirect to this page after form completion. Absolute URLS should begin with http. Relative URLs should begin with a forward slash (/)."))
     template = models.CharField(_('Template'), max_length=50, blank=True)
+    group = models.ForeignKey(Group, null=True, default=None, on_delete=models.SET_NULL)
 
     # payments
     custom_payment = models.BooleanField(_("Is Custom Payment"), default=False,
@@ -118,7 +128,7 @@ class Form(TendenciBaseModel):
         help_text=_("If checked, please add pricing options below. Leave the price blank if users can enter their own amount. Please also add an email field as a required field with type 'email'"))
     payment_methods = models.ManyToManyField("payments.PaymentMethod", blank=True)
 
-    perms = generic.GenericRelation(ObjectPermission,
+    perms = GenericRelation(ObjectPermission,
         object_id_field="object_id", content_type_field="content_type")
 
     # positions for displaying the fields
@@ -139,20 +149,22 @@ class Form(TendenciBaseModel):
     class Meta:
         verbose_name = _("Form")
         verbose_name_plural = _("Forms")
-        permissions = (("view_form", _("Can view form")),)
+#         permissions = (("view_form", _("Can view form")),)
+        app_label = 'forms'
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
     def save(self, *args, **kwargs):
         # If this is the current contact form, update checklist
         if str(self.pk) == get_setting('site', 'global', 'contact_form'):
             checklist_update('update-contact')
+        if not self.group:
+            self.group_id = get_default_group()
         super(Form, self).save(*args, **kwargs)
 
-    @models.permalink
     def get_absolute_url(self):
-        return ("form_detail", (), {"slug": self.slug})
+        return reverse('form_detail', kwargs={"slug": self.slug})
 
     def get_payment_type(self):
         if self.recurring_payment and self.custom_payment:
@@ -162,16 +174,16 @@ class Form(TendenciBaseModel):
         if self.custom_payment:
             return _("Custom Payment")
 
+    @mark_safe
     def admin_link_view(self):
         url = self.get_absolute_url()
         return "<a href='%s'>%s</a>" % (url, ugettext("View on site"))
-    admin_link_view.allow_tags = True
     admin_link_view.short_description = ""
 
+    @mark_safe
     def admin_link_export(self):
         url = reverse("admin:forms_form_export", args=(self.id,))
         return "<a href='%s'>%s</a>" % (url, ugettext("Export entries"))
-    admin_link_export.allow_tags = True
     admin_link_export.short_description = ""
 
     def has_files(self):
@@ -188,6 +200,12 @@ class FieldManager(models.Manager):
     def visible(self):
         return self.filter(visible=True)
 
+    """
+    Get all Auto-fields. (As of writing, this is only GroupSubscriptionAuto)
+    """
+    def auto_fields(self):
+        return self.filter(visible=False, field_function="GroupSubscriptionAuto")
+
 
 class Field(OrderingBaseModel):
     """
@@ -202,7 +220,7 @@ class Field(OrderingBaseModel):
     - Includes their respective values to the email's subject
     """
 
-    form = models.ForeignKey("Form", related_name="fields")
+    form = models.ForeignKey("Form", related_name="fields", on_delete=models.CASCADE)
     label = models.CharField(_("Label"), max_length=LABEL_MAX_LENGTH)
     field_type = models.CharField(_("Type"), choices=FIELD_CHOICES,
         max_length=64)
@@ -221,22 +239,23 @@ class Field(OrderingBaseModel):
         verbose_name = _("Field")
         verbose_name_plural = _("Fields")
         #order_with_respect_to = "form"
+        app_label = 'forms'
 
-    def __unicode__(self):
+    def __str__(self):
         return self.label
 
     def get_field_class(self):
         if "/" in self.field_type:
             field_class, field_widget = self.field_type.split("/")
         else:
-            field_class, field_widget = self.field_type, None
+            field_class = self.field_type
         return field_class
 
     def get_field_widget(self):
         if "/" in self.field_type:
             field_class, field_widget = self.field_type.split("/")
         else:
-            field_class, field_widget = self.field_type, None
+            field_widget = None
         return field_widget
 
     def get_choices(self):
@@ -249,7 +268,8 @@ class Field(OrderingBaseModel):
                                ('','-----------'))
             choices = initial_choices + tuple(countries)
         elif self.field_type == 'StateProvinceField':
-            choices = (('','-----------'),) + STATE_CHOICES + PROVINCE_CHOICES
+            choices = (('','-----------'),) + tuple((state, state_f.title()) for state, state_f in STATE_CHOICES) \
+                                + tuple((prov, prov_f.title()) for prov, prov_f in PROVINCE_CHOICES)
             choices = sorted(choices)
         elif self.field_function == 'Recipients':
             choices = [(label+':'+val, label) for label, val in (i.split(":") for i in self.choices.split(","))]
@@ -258,11 +278,11 @@ class Field(OrderingBaseModel):
         return choices
 
     def execute_function(self, entry, value, user=None):
-        if self.field_function == "GroupSubscription":
+        if self.field_function in ["GroupSubscription", "GroupSubscriptionAuto"]:
             if value:
                 for val in self.choices.split(','):
                     group, created = Group.objects.get_or_create(name=val.strip())
-                    if user:
+                    if user and group.allow_self_add:
                         try:
                             group_membership = GroupMembership.objects.get(group=group, member=user)
                         except GroupMembership.DoesNotExist:
@@ -280,11 +300,12 @@ class FormEntry(models.Model):
     An entry submitted via a user-built form.
     """
 
-    form = models.ForeignKey("Form", related_name="entries")
+    form = models.ForeignKey("Form", related_name="entries", on_delete=models.CASCADE)
     entry_time = models.DateTimeField(_("Date/time"))
     entry_path = models.CharField(max_length=200, blank=True, default="")
-    payment_method = models.ForeignKey('payments.PaymentMethod', null=True)
-    pricing = models.ForeignKey('Pricing', null=True)
+    payment_method = models.ForeignKey('payments.PaymentMethod', null=True, on_delete=models.SET_NULL)
+    pricing = models.ForeignKey('Pricing', null=True, on_delete=models.SET_NULL)
+    custom_price = models.DecimalField(max_digits=10, decimal_places=2, blank=True, null=True)
     creator = models.ForeignKey(User, related_name="formentry_creator",  null=True, on_delete=models.SET_NULL)
     create_dt = models.DateTimeField(auto_now_add=True)
     update_dt = models.DateTimeField(auto_now=True)
@@ -292,13 +313,21 @@ class FormEntry(models.Model):
     class Meta:
         verbose_name = _("Form entry")
         verbose_name_plural = _("Form entries")
+        app_label = 'forms'
 
-    def __unicode__(self):
-        return unicode(self.id)
+    def __str__(self):
+        return ('%s submission' % (self.form.title,))
 
-    @models.permalink
     def get_absolute_url(self):
-        return ("form_entry_detail", (), {"id": self.pk})
+        return reverse('form_entry_detail', kwargs={"id": self.pk})
+
+    @property
+    def owner(self):
+        return self.creator
+    
+    @property
+    def group(self):
+        return self.form.group
 
     def entry_fields(self):
         return self.fields.all().order_by('field__position')
@@ -376,6 +405,33 @@ class FormEntry(models.Model):
     def get_phone_number(self):
         return self.get_value_of("EmailPhoneNumber")
 
+    def get_company(self):
+        return self.get_value_of("company")
+
+    def get_address(self):
+        return self.get_value_of("address")
+
+    def get_city(self):
+        return self.get_value_of("city")
+
+    def get_region(self):
+        return self.get_value_of("region")
+
+    def get_state(self):
+        return self.get_value_of("state")
+
+    def get_zipcode(self):
+        return self.get_value_of("zipcode")
+
+    def get_position_title(self):
+        return self.get_value_of("position_title")
+ 
+    def get_referral_source(self):
+        return self.get_value_of("referral_source")
+
+    def get_notes(self):
+        return self.get_value_of("notes")
+
     def get_function_email_recipients(self):
         email_list = set()
         for entry in self.fields.order_by('field__position'):
@@ -393,7 +449,7 @@ class FormEntry(models.Model):
     def get_email_address(self):
         return self.get_type_of("emailverificationfield")
 
-     # Called by payments_pop_by_invoice_user in Payment model.
+    # Called by payments_pop_by_invoice_user in Payment model.
     def get_payment_description(self, inv):
         """
         The description will be sent to payment gateway and displayed on invoice.
@@ -413,24 +469,81 @@ class FormEntry(models.Model):
         return description
 
     def set_group_subscribers(self):
-        for entry in self.fields.filter(field__field_function="GroupSubscription"):
+        for entry in self.fields.filter(field__field_function__in=["GroupSubscription", "GroupSubscriptionAuto"]):
             entry.field.execute_function(self, entry.value, user=self.creator)
 
+    def check_and_create_user(self):
+        """
+        Check and create a new user if needed (only if payment is involved or 
+            "Subscribe to Group" functionality is selected).
+        Return the user created or None.
+        """
+        from tendenci.apps.profiles.models import Profile
+        emailfield = self.get_email_address()
+        anonymous_creator = None
+
+        if emailfield:
+            user_list = User.objects.filter(email=emailfield).order_by('-last_login')
+            if user_list:
+                anonymous_creator = user_list[0]
+            else:
+                # Create a new user only if payment is involved or 
+                # "Subscribe to Group" functionality selected
+                if get_setting('module', 'forms', 'form_submission_create_user') or \
+                         self.form.custom_payment or self.form.recurring_payment or \
+                         self.fields.filter(field__field_function__in=["GroupSubscription",
+                                                                       "GroupSubscriptionAuto"],
+                                            ).exclude(value='').exists():
+                    first_name = self.get_first_name()
+                    last_name = self.get_last_name()
+                    if not (first_name and last_name):
+                        full_name = self.get_full_name()
+                        if full_name:
+                            name_list = full_name.split(" ", 1)
+                            first_name = name_list[0]
+                            last_name = name_list[1] if len(name_list) > 1 else ""
+
+                    anonymous_creator = User(username=emailfield[:30], email=emailfield,
+                                             first_name=first_name, last_name=last_name)
+                    anonymous_creator.set_unusable_password()
+                    anonymous_creator.is_active = False
+                    anonymous_creator.save()
+                    
+                    anonymous_profile = Profile(user=anonymous_creator,
+                                                owner=anonymous_creator,
+                                                creator=anonymous_creator,
+                                                phone=self.get_phone_number(),
+                                                address=self.get_address(),
+                                                company=self.get_company(),
+                                                city=self.get_city(),
+                                                region=self.get_region(),
+                                                state=self.get_state(),
+                                                zipcode=self.get_zipcode(),
+                                                position_title=self.get_position_title(),
+                                                referral_source=self.get_referral_source(),
+                                                notes=self.get_notes(),
+                                                )
+                    anonymous_profile.save()
+
+        return anonymous_creator
+        
+
 
 class FieldEntry(models.Model):
     """
     A single field value for a form entry submitted via a user-built form.
     """
 
-    entry = models.ForeignKey("FormEntry", related_name="fields")
-    field = models.ForeignKey("Field", related_name="field")
+    entry = models.ForeignKey("FormEntry", related_name="fields", on_delete=models.CASCADE)
+    field = models.ForeignKey("Field", related_name="field", on_delete=models.CASCADE)
     value = models.CharField(max_length=FIELD_MAX_LENGTH)
 
     class Meta:
         verbose_name = _("Form field entry")
         verbose_name_plural = _("Form field entries")
+        app_label = 'forms'
 
-    def __unicode__(self):
+    def __str__(self):
         return ('%s: %s' % (self.field.label, self.value))
 
     def include_in_email(self):
@@ -449,7 +562,7 @@ class Pricing(models.Model):
     """
     Pricing options for custom payment forms.
     """
-    form = models.ForeignKey('Form')
+    form = models.ForeignKey('Form', on_delete=models.CASCADE)
     label = models.CharField(max_length=100)
     description = models.TextField(_("Pricing Description"), blank=True)
     price = models.DecimalField(
@@ -476,8 +589,9 @@ class Pricing(models.Model):
 
     class Meta:
         ordering = ["pk"]
+        app_label = 'forms'
 
-    def __unicode__(self):
+    def __str__(self):
         currency_symbol = get_setting("site", "global", "currencysymbol")
         if not currency_symbol:
             currency_symbol = '$'
