@@ -7,6 +7,7 @@ from django.urls import reverse
 from tendenci.apps.invoices.models import Invoice
 from tendenci.apps.site_settings.utils import get_setting
 from tendenci.apps.forms_builder.forms.models import FormEntry, FieldEntry
+from tendenci.apps.base.utils import escape_csv
 
 def generate_admin_email_body(entry, form_for_form, user=None):
     """
@@ -66,7 +67,7 @@ def generate_email_subject(form, form_entry):
                 p = re.compile(r'(-\s+)?\[%s\]' % label, re.IGNORECASE)
             else:
                 p = re.compile(r'\[%s\]' % label, re.IGNORECASE)
-            subject = p.sub(re.escape(value), subject)
+            subject = p.sub(value, subject)
 
         # title
         p = re.compile(r'\[title\]', re.IGNORECASE)
@@ -193,7 +194,7 @@ def form_entries_to_csv_writer(csv_writer, form):
             row[-1] = entry_time
 
         for field_entry in values:
-            value = field_entry.value
+            value = escape_csv(field_entry.value)
             # Create download URL for file fields.
 #             if field_entry.field_id in file_field_ids:
 #                 url = reverse("admin:forms_form_file", args=(field_entry.id,))
