@@ -1,17 +1,19 @@
 from django.contrib import admin
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
 
-from tendenci.core.perms.admin import TendenciBaseModelAdmin
+from tendenci.apps.perms.admin import TendenciBaseModelAdmin
 from tendenci.apps.stories.models import Story, Rotator
 from tendenci.apps.stories.forms import StoryAdminForm
 from tendenci.apps.stories.utils import copy_story
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.perms.utils import update_perms_and_save
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.perms.utils import update_perms_and_save
+from tendenci.apps.theme.templatetags.static import static
 
 
 class StoryAdmin(TendenciBaseModelAdmin):
-    list_display = ('image_preview', 'title', 'tags', 'status', 'position')
+    list_display = ('image_preview', 'title', 'tags', 'video_embed_url', 'status', 'position')
     search_fields = ('title', 'content')
     list_editable = ['title', 'tags', 'position']
     actions = ['clone_story']
@@ -19,6 +21,7 @@ class StoryAdmin(TendenciBaseModelAdmin):
                       'fields': ['title',
                                  'content',
                                  'photo_upload',
+                                 'video_embed_url',
                                  'full_story_link',
                                  'link_title',
                                  'rotator',
@@ -44,13 +47,13 @@ class StoryAdmin(TendenciBaseModelAdmin):
 
     class Media:
         css = {
-            "all": ("css/websymbols.css",)
+            "all": (static("css/websymbols.css"),)
         }
         js = (
-            '//ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js',
-            '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.0/jquery-ui.min.js',
-            'js/admin/admin-list-reorder.js',
-            'js/global/tinymce.event_handlers.js',
+            '//ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js',
+            '//ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js',
+            static('js/admin/admin-list-reorder.js'),
+            static('js/global/tinymce.event_handlers.js'),
         )
 
     def save_model(self, request, object, form, change):
@@ -76,6 +79,7 @@ class StoryAdmin(TendenciBaseModelAdmin):
             EventLog.objects.log(**log_defaults)
         return object
 
+    @mark_safe
     def image_preview(self, obj):
         if obj.image:
             args = [obj.image.pk]
@@ -87,7 +91,6 @@ class StoryAdmin(TendenciBaseModelAdmin):
             return '<img src="%s" alt="%s" title="%s" />' % (reverse('file', args=args), alt, alt)
         else:
             return _("No image")
-    image_preview.allow_tags = True
     image_preview.short_description = _('Image')
 
     def clone_story(self, request, queryset):
@@ -104,6 +107,7 @@ class StoryInline(admin.TabularInline):
     readonly_fields = ('image_preview','title')
     ordering = ('rotator_position','title')
 
+    @mark_safe
     def image_preview(self, obj):
         if obj.image:
             args = [obj.image.pk]
@@ -115,7 +119,6 @@ class StoryInline(admin.TabularInline):
             return '<img src="%s" alt="%s" title="%s" />' % (reverse('file', args=args), alt, alt)
         else:
             return _("No image")
-    image_preview.allow_tags = True
     image_preview.short_description = _('Image')
 
 
@@ -124,11 +127,11 @@ class RotatorAdmin(admin.ModelAdmin):
 
     class Media:
         js = (
-            '//ajax.googleapis.com/ajax/libs/jquery/2.1.1/jquery.min.js',
-            '//ajax.googleapis.com/ajax/libs/jqueryui/1.11.0/jquery-ui.min.js',
+            '//ajax.googleapis.com/ajax/libs/jquery/3.4.1/jquery.min.js',
+            '//ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js',
             'js/admin/rotator-story-inline-ordering.js',
         )
-        css = {'all': ['css/admin/dynamic-inlines-with-sort.css'], }
+        css = {'all': [static('css/admin/dynamic-inlines-with-sort.css')], }
 
 
 admin.site.register(Story, StoryAdmin)
