@@ -1,18 +1,18 @@
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
-from tendenci.core.registry import site
-from tendenci.core.registry.base import CoreRegistry, lazy_reverse
+from tendenci.apps.registry.sites import site
+from tendenci.apps.registry.base import CoreRegistry, lazy_reverse
 from tendenci.apps.stories.models import Story
+from tendenci.apps.theme.templatetags.static import static
 
 
 class StoryRegistry(CoreRegistry):
     version = '1.0'
-    author = _('Schipul - The Web Marketing Company')
-    author_email = 'programmers@schipul.com'
-    description = _('Stories can be created and rotated on ' \
+    author = _('Tendenci - The Open Source AMS for Associations')
+    author_email = 'programmers@tendenci.com'
+    description = _('Stories can be created and rotated on '
                   'a specified area on the site')
-    icon = '%simages/icons/stories-color-64x64.png' % settings.STATIC_URL
+    icon = static('images/icons/stories-color-64x64.png')
 
     event_logs = {
         'story':{
